pub enum AncillaryFilesManifestVerifyError {
FileHashMismatch {
file_path: PathBuf,
expected_hash: String,
actual_hash: String,
},
HashCompute {
file_path: PathBuf,
source: StdError,
},
}Expand description
Errors that can occur when verifying the integrity of the data in the manifest
Variants
FileHashMismatch
The hash of a file does not match the hash in the manifest
Fields
HashCompute
An error occurred while computing the hash of a file