pub enum LedgerStateSnapshot {
Legacy {
path: PathBuf,
slot_number: SlotNumber,
filename: OsString,
},
InMemoryUpTo10_6 {
path: PathBuf,
slot_number: SlotNumber,
folder_name: OsString,
},
InMemoryFrom10_7 {
path: PathBuf,
slot_number: SlotNumber,
folder_name: OsString,
},
}Expand description
Represent a ledger file in a Cardano node database directory
Variants
Legacy
Snapshot of a legacy ledger state (before UTxO-HD)
Fields
slot_number: SlotNumberThe ledger file slot number
InMemoryUpTo10_6
Snapshot of a UTxO-HD in-memory ledger state (Cardano node up to 10.6)
Fields
slot_number: SlotNumberThe ledger file slot number
InMemoryFrom10_7
Snapshot of a UTxO-HD in-memory ledger state (Cardano node 10.7 and above)
Implementations
Sourceimpl LedgerStateSnapshot
impl LedgerStateSnapshot
Sourcepub const IN_MEMORY_META: &'static str = "meta"
pub const IN_MEMORY_META: &'static str = "meta"
Filename of the in-memory ledger snapshot ‘meta’ file
Sourcepub const IN_MEMORY_STATE: &'static str = "state"
pub const IN_MEMORY_STATE: &'static str = "state"
Filename of the in-memory ledger snapshot ‘state’ file
Sourcepub const IN_MEMORY_TABLES: &'static str = "tables"
pub const IN_MEMORY_TABLES: &'static str = "tables"
Directory name of the in-memory ledger snapshot ‘tables’ folder
Sourcepub const IN_MEMORY_TVAR: &'static str = "tvar"
pub const IN_MEMORY_TVAR: &'static str = "tvar"
Filename of the in-memory ledger snapshot ‘tables/tvar’ file
Sourcepub fn legacy(
path: PathBuf,
slot_number: SlotNumber,
filename: OsString,
) -> Self
pub fn legacy( path: PathBuf, slot_number: SlotNumber, filename: OsString, ) -> Self
LedgerStateSnapshot::Legacy factory
Sourcepub fn from_path(path: &Path) -> Option<LedgerStateSnapshot>
pub fn from_path(path: &Path) -> Option<LedgerStateSnapshot>
Convert a path to a LedgerStateSnapshot if it satisfies the constraints.
The constraints are:
- legacy state snapshot: the path must be a file, the filename should only contain a number (no extension).
Sourcepub fn list_all_in_dir(
dir: &Path,
) -> Result<Vec<LedgerStateSnapshot>, LedgerStateSnapshotListingError>
pub fn list_all_in_dir( dir: &Path, ) -> Result<Vec<LedgerStateSnapshot>, LedgerStateSnapshotListingError>
List all LedgerStateSnapshot in a given directory.
Sourcepub fn get_files_relative_path(&self) -> Vec<PathBuf>
pub fn get_files_relative_path(&self) -> Vec<PathBuf>
Return paths to all files that constitute this snapshot
Returned paths are relative to the cardano node database ledger dir
Sourcepub fn slot_number(&self) -> SlotNumber
pub fn slot_number(&self) -> SlotNumber
Return the slot number when this snapshot was taken